@@ -9,7 +9,8 @@ import warnings
 import numpy as np
 
 import xobjects as xo
-import xtrack.linear_normal_form as lnf
+from .general import _print
+
 
 import xpart as xp # To get the right Particles class depending on pyheatail interface state
 
@@ -172,7 +173,7 @@ def build_particles(_context=None, _buffer=None, _offset=None, _capacity=None,
     # Move other input parameters to cpu if needed
     # Generated by:
     # for nn in 'x px y py zeta delta x_norm px_norm y_norm py_norm'.split():
-    #     print(f'{nn} = ({nn}.get() if hasattr({nn}, "get") else {nn})')
+    #     _print(f'{nn} = ({nn}.get() if hasattr({nn}, "get") else {nn})')
     x = (x.get() if hasattr(x, "get") else x)
     px = (px.get() if hasattr(px, "get") else px)
     y = (y.get() if hasattr(y, "get") else y)
@@ -274,6 +275,7 @@ def build_particles(_context=None, _buffer=None, _offset=None, _capacity=None,
             WW = tw_state.W_matrix
             particle_on_co = tw_state.particle_on_co
         elif W_matrix is None and R_matrix is not None:
+            import xtrack.linear_normal_form as lnf
             WW, _, _ = lnf.compute_linear_normal_form(
                                 R_matrix,
                                 **kwargs)
